@@ -159,7 +159,7 @@ int mini_sscanf(const char *s1, const char *fmt, ...)
             }
             else if (fmt[1] == 'u')
             {
-                k += sscanf(s, "%u%n", va_arg(va, int *), &n);
+                k += sscanf(s, "%u%n", va_arg(va, unsigned int *), &n);
                 s += n;
                 fmt += 2;
             }
@@ -171,7 +171,7 @@ int mini_sscanf(const char *s1, const char *fmt, ...)
             }
             else if (fmt[1] == 'l' && fmt[2] == 'u')
             {
-                k += sscanf(s, "%lu%n", va_arg(va, long *), &n);
+                k += sscanf(s, "%lu%n", va_arg(va, unsigned long *), &n);
                 s += n;
                 fmt += 3;
             }
@@ -271,10 +271,10 @@ int fsize(char *fname)
 void msleep(long msec)
 {
 #ifdef LINUX
-    timespec req;
+    // timespec req;
     timeval tv;
-    req.tv_sec = 0;
-    req.tv_nsec = msec * 1000000;
+    // req.tv_sec = 0;
+    // req.tv_nsec = msec * 1000000;
     // int  	nanosleep(const struct timespec *req, struct timespec
     // *remain)
     /*while (nanosleep(&req, &req))
@@ -353,7 +353,7 @@ TBloon::TBloon(QWidget *parent) : QLabel(parent)
     // Construct a 1-second timeline with a frame range of 0 - 100
     timeLine = new QTimeLine(100000, this);
     timeLine->setFrameRange(0, 20000);
-    timeLine->setCurveShape(QTimeLine::EaseOutCurve);
+    timeLine->easingCurve();
     //	timeLine->set(0, 20000);
     connect(timeLine, SIGNAL(frameChanged(int)), this, SLOT(update(int)));
 }
@@ -449,7 +449,7 @@ TFrame::TFrame(QWidget *parent) : QLabel(parent)
 
     timeLine = new QTimeLine(2000, this);
     timeLine->setFrameRange(0, 100);
-    connect(timeLine, SIGNAL(frameChanged(int)), this, SLOT(setValue(int)));
+    connect(timeLine, &QTimeLine::frameChanged, this, &TFrame::setValue);
 }
 
 /*
@@ -492,7 +492,7 @@ void TFrame::draw(QPainter &p)
     //	if(!isVisible()) 	return;
     return;
     int h = fontMetrics().height() + 3;
-    int w = fontMetrics().width(text) + 9;
+    int w = fontMetrics().horizontalAdvance(text) + 9;
     setFixedSize(w, h);
     //	QFont font("Adobe Helvetica"); // helvetica & No-Antialias
     // 	font.setPixelSize(10);
@@ -500,9 +500,6 @@ void TFrame::draw(QPainter &p)
     //	p.drawRoundRect(rect(),10,10);
     //	p.fillRect ( cr,QColor(0,0,0));
     QColor bg = QColor(0, 0, 0, 120);
-#if QT_VERSION < 0x040400
-    p.fillRect(rect(), QColor(0, 0, 0, 120));
-#else
     // p.fillRect(rect(),QColor(0,0,0,90));
 
     //	p.setPen(QColor(0,255,155)); // less visually obtrusive than
@@ -511,8 +508,6 @@ void TFrame::draw(QPainter &p)
     //	p.drawRoundedRect(0,0,w,h, 4, 4);
     p.fillRect(rect(), bg);
 
-#endif
-
     p.setPen(QColor(0, 255, 155)); // less visually obtrusive than black
     p.drawText(0, 0, w, h, Qt::AlignVCenter | Qt::AlignHCenter, text);
 }
@@ -769,6 +764,8 @@ SearchBox::SearchBox(QWidget *parent) : QLineEdit(parent)
 
     setFocus(Qt::ActiveWindowFocusReason);
 
+    connect (this, &QLineEdit::textChanged, this, &SearchBox::onTextChanged);
+
     QList<QToolButton*> list = findChildren<QToolButton*>();
     if (!list.isEmpty())
     {
@@ -778,14 +775,6 @@ SearchBox::SearchBox(QWidget *parent) : QLineEdit(parent)
     }
 }
 
-void SearchBox::event_cursor_moved(QMouseEvent *e) { move(e->x(), e->y()); }
-
-void SearchBox::event_xbutton_clicked()
-{
-    QKeyEvent ke(QEvent::KeyPress, Qt::Key_Escape, Qt::NoModifier); // temp..
-    keyPressEvent(&ke);
-}
-
 LogBox::LogBox(QWidget *p) : QLabel(p)
 {
     text = new QTextEdit(p);
@@ -821,14 +810,14 @@ ControlBar::ControlBar(QWidget *parent) : QFrame(parent)
     b_tree->setFocusPolicy(Qt::NoFocus);
 
     search_box = new SearchBox(this);
-    connect(b_linear, SIGNAL(clicked()), SLOT(linear_clicked()));
-    connect(b_tree, SIGNAL(clicked()), SLOT(tree_clicked()));
+    connect(b_linear, &QAbstractButton::clicked, this, &ControlBar::linear_clicked);
+    connect(b_tree, &QAbstractButton::clicked, this, &ControlBar::tree_clicked);
 
     if (flag_thread_ok)
     {
         check_thread = new QCheckBox( ( tr( "Thread" ) ), this);
         check_thread->setFocusPolicy(Qt::NoFocus);
-        connect(check_thread, SIGNAL(clicked()), SLOT(show_thread_clicked()));
+        connect(check_thread, &QAbstractButton::clicked, this, &ControlBar::show_thread_clicked);
         check_thread->setChecked(flag_show_thread);
     }
 
@@ -855,7 +844,7 @@ ControlBar::ControlBar(QWidget *parent) : QFrame(parent)
     pauseButton->setToolTip(tr("Pause (Ctrl+Space)"));
     pauseButton->setFocusPolicy(Qt::NoFocus);
     pauseButton->setAutoRaise(true);
-    connect(pauseButton, SIGNAL(clicked(bool)), SLOT(setPaused(bool)));
+    connect(pauseButton, &QAbstractButton::clicked, this, &ControlBar::setPaused);
 
     layout->addWidget(pauseButton);
 
@@ -901,8 +890,6 @@ void ControlBar::show_thread_clicked()
     emit need_refresh();
 }
 
-void ServerAdaptor::accelerate() {}
-
 char *read_proc_file(const char *fname, int pid = -1, int tgid = -1); // Temp
 void init_misc(QWidget * /*main*/)
 {
@@ -956,7 +943,5 @@ void QTabWidgetX::showTab(bool flag)
     else
         tb->hide();
 // if flag_useTabView == false
-#if QT_VERSION > 0x040500
 //	setDocumentMode (true); // QT 4.5
-#endif
 }
