@@ -39,12 +39,12 @@
     <message>
         <location filename="../prefs.cpp" line="59"/>
         <source>Exit on closing</source>
-        <translation type="unfinished"></translation>
+        <translation>Keluar saat ditutup</translation>
     </message>
     <message>
         <location filename="../prefs.cpp" line="60"/>
         <source>Remember Position</source>
-        <translation type="unfinished"></translation>
+        <translation>Ingat posisi</translation>
     </message>
     <message>
         <location filename="../prefs.cpp" line="68"/>
@@ -221,42 +221,42 @@ keluar dengan status </translation>
 <context>
     <name>ControlBar</name>
     <message>
-        <location filename="../misc.cpp" line="817"/>
+        <location filename="../misc.cpp" line="806"/>
         <source>Linear</source>
         <translation>Linear</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="820"/>
+        <location filename="../misc.cpp" line="809"/>
         <source>Tree</source>
         <translation>Tree</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="829"/>
+        <location filename="../misc.cpp" line="818"/>
         <source>Thread</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="836"/>
+        <location filename="../misc.cpp" line="825"/>
         <source>All Processes</source>
         <translation>Semua Proses</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="837"/>
+        <location filename="../misc.cpp" line="826"/>
         <source>Your Processes</source>
         <translation>Proses Anda</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="838"/>
+        <location filename="../misc.cpp" line="827"/>
         <source>Non-Root Processes</source>
         <translation>Proses Non-Root</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="839"/>
+        <location filename="../misc.cpp" line="828"/>
         <source>Running Processes</source>
         <translation>Proses Berjalan</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="855"/>
+        <location filename="../misc.cpp" line="844"/>
         <source>Pause (Ctrl+Space)</source>
         <translation>Jeda (Ctrl + Spasi)</translation>
     </message>
@@ -425,27 +425,27 @@ keluar dengan status </translation>
         <translation>Qps Watchdog</translation>
     </message>
     <message>
-        <location filename="../execwindow.cpp" line="94"/>
+        <location filename="../execwindow.cpp" line="95"/>
         <source>%1 exit with code %2</source>
         <translation>%1 keluar dengan kode %2</translation>
     </message>
     <message>
-        <location filename="../execwindow.cpp" line="96"/>
+        <location filename="../execwindow.cpp" line="97"/>
         <source>Close</source>
         <translation>Tutup</translation>
     </message>
     <message>
-        <location filename="../execwindow.cpp" line="102"/>
+        <location filename="../execwindow.cpp" line="103"/>
         <source>%1 [running]</source>
         <translation>%1 [berjalan]</translation>
     </message>
     <message>
-        <location filename="../execwindow.cpp" line="103"/>
+        <location filename="../execwindow.cpp" line="104"/>
         <source>terminate command</source>
         <translation>mengakhiri perintah</translation>
     </message>
     <message>
-        <location filename="../execwindow.cpp" line="112"/>
+        <location filename="../execwindow.cpp" line="113"/>
         <source>Error %1 : [%2] Maybe command not found</source>
         <translation>Kesalahan %1: [%2] Mungkin perintah tidak ditemukan</translation>
     </message>
@@ -684,512 +684,512 @@ keluar dengan status </translation>
 <context>
     <name>Proc</name>
     <message>
-        <location filename="../proc.cpp" line="2876"/>
+        <location filename="../proc.cpp" line="2850"/>
         <source>PID</source>
         <translation>PID</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2876"/>
+        <location filename="../proc.cpp" line="2850"/>
         <source>Process ID</source>
         <translation>ID proses</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2878"/>
+        <location filename="../proc.cpp" line="2852"/>
         <source>TGID</source>
         <translation>TGID</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2878"/>
+        <location filename="../proc.cpp" line="2852"/>
         <source>Task group ID ( parent of threads )</source>
         <translation type="unfinished">Task group ID ( parent of threads )</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2880"/>
+        <location filename="../proc.cpp" line="2854"/>
         <source>PPID</source>
         <translation>PPID</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2880"/>
+        <location filename="../proc.cpp" line="2854"/>
         <source>Parent process ID</source>
         <translation type="unfinished">Parent process ID</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2882"/>
+        <location filename="../proc.cpp" line="2856"/>
         <source>PGID</source>
         <translation>PGID</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2882"/>
+        <location filename="../proc.cpp" line="2856"/>
         <source>Process group ID</source>
         <translation>ID grup proses</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2884"/>
+        <location filename="../proc.cpp" line="2858"/>
         <source>SID</source>
         <translation>SID</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2884"/>
+        <location filename="../proc.cpp" line="2858"/>
         <source>Session ID</source>
         <translation>ID sesi</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2886"/>
+        <location filename="../proc.cpp" line="2860"/>
         <source>TTY</source>
         <translation>TTY</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2886"/>
+        <location filename="../proc.cpp" line="2860"/>
         <source>Terminal</source>
         <translation>Terminal</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2888"/>
+        <location filename="../proc.cpp" line="2862"/>
         <source>TPGID</source>
         <translation>TPGID</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2888"/>
+        <location filename="../proc.cpp" line="2862"/>
         <source>Process group ID of tty owner</source>
         <translation type="unfinished">Process group ID of tty owner</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2890"/>
+        <location filename="../proc.cpp" line="2864"/>
         <source>USER</source>
         <translation type="unfinished">USER</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2890"/>
+        <location filename="../proc.cpp" line="2864"/>
         <source>Owner (*=suid root, +=suid a user)</source>
         <translation>Pemilik (*=suid root, +=suid pengguna)</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2892"/>
+        <location filename="../proc.cpp" line="2866"/>
         <source>GROUP</source>
         <translation>GRUP</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2892"/>
+        <location filename="../proc.cpp" line="2866"/>
         <source>Group name (*=sgid other)</source>
         <translation>Nama grup (*=sgid lain)</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2894"/>
+        <location filename="../proc.cpp" line="2868"/>
         <source>UID</source>
         <translation>UID</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2894"/>
+        <location filename="../proc.cpp" line="2868"/>
         <source>Real user ID</source>
         <translation>ID Pengguna Asli</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2896"/>
+        <location filename="../proc.cpp" line="2870"/>
         <source>EUID</source>
         <translation>EUID</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2896"/>
+        <location filename="../proc.cpp" line="2870"/>
         <source>Effective user ID</source>
         <translation>ID Pengguna Efektif</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2898"/>
+        <location filename="../proc.cpp" line="2872"/>
         <source>SUID</source>
         <translation>SUID</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2898"/>
+        <location filename="../proc.cpp" line="2872"/>
         <source>Saved user ID (Posix)</source>
         <translation>ID pengguna tersimpan (Posix)</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2900"/>
+        <location filename="../proc.cpp" line="2874"/>
         <source>FSUID</source>
         <translation>FSUID</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2900"/>
+        <location filename="../proc.cpp" line="2874"/>
         <source>File system user ID</source>
         <translation>Berkas sistem ID Pengguna</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2902"/>
+        <location filename="../proc.cpp" line="2876"/>
         <source>GID</source>
         <translation>GID</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2902"/>
+        <location filename="../proc.cpp" line="2876"/>
         <source>Real group ID</source>
         <translation>Real ID grup</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2904"/>
+        <location filename="../proc.cpp" line="2878"/>
         <source>EGID</source>
         <translation>EGID</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2904"/>
+        <location filename="../proc.cpp" line="2878"/>
         <source>Effective group ID</source>
         <translation>ID grup Efektif</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2906"/>
+        <location filename="../proc.cpp" line="2880"/>
         <source>SGID</source>
         <translation>SGID</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2906"/>
+        <location filename="../proc.cpp" line="2880"/>
         <source>Saved group ID (Posix)</source>
         <translation>ID grup tersimpan (Posix)</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2908"/>
+        <location filename="../proc.cpp" line="2882"/>
         <source>FSGID</source>
         <translation>FSGID</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2908"/>
+        <location filename="../proc.cpp" line="2882"/>
         <source>File system group ID</source>
         <translation>Berkas sistem ID grup</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2910"/>
+        <location filename="../proc.cpp" line="2884"/>
         <source>PRI</source>
         <translation>PRI</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2910"/>
+        <location filename="../proc.cpp" line="2884"/>
         <source>Dynamic priority</source>
         <translation>Prioritas Dinamis</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2912"/>
+        <location filename="../proc.cpp" line="2886"/>
         <source>NICE</source>
         <translation>NICE</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2912"/>
+        <location filename="../proc.cpp" line="2886"/>
         <source>Scheduling favour (higher -&gt; less cpu time)</source>
         <translation>Urutan Jadwal (tertinggi -&gt; waktu cpu minim)</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2914"/>
+        <location filename="../proc.cpp" line="2888"/>
         <source>NLWP</source>
         <translation>NLWP</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2914"/>
+        <location filename="../proc.cpp" line="2888"/>
         <source>Number of tasks(threads) in task group</source>
         <translation>Jumlah task(thread) dalam grup task</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2916"/>
+        <location filename="../proc.cpp" line="2890"/>
         <source>PLCY</source>
         <translation>PLCY</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2916"/>
+        <location filename="../proc.cpp" line="2890"/>
         <source>Scheduling policy</source>
         <translation>Kebijakan Jadwal</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2918"/>
+        <location filename="../proc.cpp" line="2892"/>
         <source>RPRI</source>
         <translation>RPRI</translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2918"/>
+        <location filename="../proc.cpp" line="2892"/>
         <source>Realtime priority (0-99, more is better)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2920"/>
+        <location filename="../proc.cpp" line="2894"/>
         <source>TMS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2920"/>
+        <location filename="../proc.cpp" line="2894"/>
         <source>Time slice in milliseconds</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2922"/>
+        <location filename="../proc.cpp" line="2896"/>
         <source>%SAVG</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2922"/>
+        <location filename="../proc.cpp" line="2896"/>
         <source>Percentage average sleep time (-1 -&gt; N/A)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2924"/>
+        <location filename="../proc.cpp" line="2898"/>
         <source>CPUSET</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2924"/>
+        <location filename="../proc.cpp" line="2898"/>
         <source>Affinity CPU mask (0 -&gt; API not supported)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2926"/>
+        <location filename="../proc.cpp" line="2900"/>
         <source>MAJFLT</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2926"/>
+        <location filename="../proc.cpp" line="2900"/>
         <source>Number of major faults (disk access)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2928"/>
+        <location filename="../proc.cpp" line="2902"/>
         <source>MINFLT</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2928"/>
+        <location filename="../proc.cpp" line="2902"/>
         <source>Number of minor faults (no disk access)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2931"/>
+        <location filename="../proc.cpp" line="2905"/>
         <source>VSIZE</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2931"/>
+        <location filename="../proc.cpp" line="2905"/>
         <source>Virtual image size of process</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2933"/>
+        <location filename="../proc.cpp" line="2907"/>
         <source>RSS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2933"/>
+        <location filename="../proc.cpp" line="2907"/>
         <source>Resident set size</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2935"/>
+        <location filename="../proc.cpp" line="2909"/>
         <source>MEM</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2935"/>
+        <location filename="../proc.cpp" line="2909"/>
         <source>memory usage (RSS-SHARE)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2937"/>
+        <location filename="../proc.cpp" line="2911"/>
         <source>TRS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2937"/>
+        <location filename="../proc.cpp" line="2911"/>
         <source>Text(code) resident set size</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2939"/>
+        <location filename="../proc.cpp" line="2913"/>
         <source>DRS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2939"/>
+        <location filename="../proc.cpp" line="2913"/>
         <source>Data resident set size(malloc+global variable)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2941"/>
+        <location filename="../proc.cpp" line="2915"/>
         <source>STACK</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2941"/>
+        <location filename="../proc.cpp" line="2915"/>
         <source>Stack size</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2943"/>
+        <location filename="../proc.cpp" line="2917"/>
         <source>SHARE</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2943"/>
+        <location filename="../proc.cpp" line="2917"/>
         <source>Shared memory with other libs</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2945"/>
+        <location filename="../proc.cpp" line="2919"/>
         <source>SWAP</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2945"/>
+        <location filename="../proc.cpp" line="2919"/>
         <source>Kbytes on swap device</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2947"/>
+        <location filename="../proc.cpp" line="2921"/>
         <source>IO_R</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2947"/>
+        <location filename="../proc.cpp" line="2921"/>
         <source>io read (file)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2949"/>
+        <location filename="../proc.cpp" line="2923"/>
         <source>IO_W</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2949"/>
+        <location filename="../proc.cpp" line="2923"/>
         <source>io write (file)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2951"/>
+        <location filename="../proc.cpp" line="2925"/>
         <source>DT</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2951"/>
+        <location filename="../proc.cpp" line="2925"/>
         <source>Number of dirty (non-written) pages</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2953"/>
+        <location filename="../proc.cpp" line="2927"/>
         <source>STAT</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2953"/>
+        <location filename="../proc.cpp" line="2927"/>
         <source>State of the process </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2955"/>
+        <location filename="../proc.cpp" line="2929"/>
         <source>FLAGS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2955"/>
+        <location filename="../proc.cpp" line="2929"/>
         <source>Process flags (hex)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2957"/>
+        <location filename="../proc.cpp" line="2931"/>
         <source>WCHAN</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2957"/>
+        <location filename="../proc.cpp" line="2931"/>
         <source>Kernel function where process is sleeping</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2959"/>
+        <location filename="../proc.cpp" line="2933"/>
         <source>%WCPU</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2959"/>
+        <location filename="../proc.cpp" line="2933"/>
         <source>Weighted percentage of CPU (30 s average)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2961"/>
+        <location filename="../proc.cpp" line="2935"/>
         <source>%CPU</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2961"/>
+        <location filename="../proc.cpp" line="2935"/>
         <source>Percentage of CPU used since last update</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2963"/>
+        <location filename="../proc.cpp" line="2937"/>
         <source>%MEM</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2963"/>
+        <location filename="../proc.cpp" line="2937"/>
         <source>Percentage of memory used (RSS/total mem)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2965"/>
+        <location filename="../proc.cpp" line="2939"/>
         <source>START</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2965"/>
+        <location filename="../proc.cpp" line="2939"/>
         <source>Time process started</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2967"/>
+        <location filename="../proc.cpp" line="2941"/>
         <source>TIME</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2967"/>
+        <location filename="../proc.cpp" line="2941"/>
         <source>Total CPU time used since start</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2969"/>
+        <location filename="../proc.cpp" line="2943"/>
         <source>CPU</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2969"/>
+        <location filename="../proc.cpp" line="2943"/>
         <source>CPU the process is executing on (SMP system)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2971"/>
+        <location filename="../proc.cpp" line="2945"/>
         <source>the process name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2971"/>
+        <location filename="../proc.cpp" line="2945"/>
         <source>Process Name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2975"/>
+        <location filename="../proc.cpp" line="2949"/>
         <source>CWD</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2975"/>
+        <location filename="../proc.cpp" line="2949"/>
         <source>Current working directory</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2976"/>
+        <location filename="../proc.cpp" line="2950"/>
         <source>ROOT</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2976"/>
+        <location filename="../proc.cpp" line="2950"/>
         <source>Root directory of process</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2979"/>
+        <location filename="../proc.cpp" line="2953"/>
         <source>COMMAND_LINE</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../proc.cpp" line="2979"/>
+        <location filename="../proc.cpp" line="2953"/>
         <source>Command line that started the process</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1197,17 +1197,17 @@ keluar dengan status </translation>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../qps.cpp" line="1846"/>
+        <location filename="../qps.cpp" line="1845"/>
         <source>Show</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qps.cpp" line="1849"/>
+        <location filename="../qps.cpp" line="1848"/>
         <source>Hide</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qps.cpp" line="1853"/>
+        <location filename="../qps.cpp" line="1852"/>
         <source>Quit</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1311,7 +1311,7 @@ keluar dengan status </translation>
     </message>
     <message>
         <location filename="../qps.cpp" line="282"/>
-        <location filename="../qps.cpp" line="1894"/>
+        <location filename="../qps.cpp" line="1893"/>
         <source>About</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1465,6 +1465,11 @@ keluar dengan status </translation>
         <source>Show Graph</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../qps.cpp" line="793"/>
+        <source>Show Control Bar</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../qps.cpp" line="804"/>
         <source>Include Child Times</source>
@@ -1481,87 +1486,87 @@ keluar dengan status </translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qps.cpp" line="1017"/>
+        <location filename="../qps.cpp" line="1016"/>
         <source>Quit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qps.cpp" line="1336"/>
-        <location filename="../qps.cpp" line="1367"/>
-        <location filename="../qps.cpp" line="1374"/>
-        <location filename="../qps.cpp" line="1395"/>
-        <location filename="../qps.cpp" line="1429"/>
-        <location filename="../qps.cpp" line="1524"/>
+        <location filename="../qps.cpp" line="1335"/>
+        <location filename="../qps.cpp" line="1366"/>
+        <location filename="../qps.cpp" line="1373"/>
+        <location filename="../qps.cpp" line="1394"/>
+        <location filename="../qps.cpp" line="1428"/>
+        <location filename="../qps.cpp" line="1523"/>
         <source>Permission denied</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qps.cpp" line="1337"/>
+        <location filename="../qps.cpp" line="1336"/>
         <source>You do not have permission to renice the selected processes. Only the process owner and the super-user are allowed to do that.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qps.cpp" line="1368"/>
+        <location filename="../qps.cpp" line="1367"/>
         <source>You do not have permission to renice process %1 (%2).Only the process owner and the super-user are allowed to do that.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qps.cpp" line="1375"/>
+        <location filename="../qps.cpp" line="1374"/>
         <source>Only the super-user may lower the nice value of a process.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qps.cpp" line="1396"/>
+        <location filename="../qps.cpp" line="1395"/>
         <source>Only the super-user may change the scheduling policy and static priority.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qps.cpp" line="1430"/>
+        <location filename="../qps.cpp" line="1429"/>
         <source>You do not have permission to change the scheduling and/or priority of process %1 (%2). Only the super-user may do that.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qps.cpp" line="1491"/>
+        <location filename="../qps.cpp" line="1490"/>
         <source>Do you really want to terminate the selected process(es)?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qps.cpp" line="1493"/>
+        <location filename="../qps.cpp" line="1492"/>
         <source>Do you really want to hang up the selected process(es)?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qps.cpp" line="1495"/>
+        <location filename="../qps.cpp" line="1494"/>
         <source>Do you really want to kill the selected process(es)?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qps.cpp" line="1504"/>
+        <location filename="../qps.cpp" line="1503"/>
         <source>Question</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qps.cpp" line="1525"/>
+        <location filename="../qps.cpp" line="1524"/>
         <source>You do not have permission to send a signal to process %1 (%2). Only the super-user and the owner of the process may send signals to it.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qps.cpp" line="1910"/>
+        <location filename="../qps.cpp" line="1909"/>
         <source>&lt;center&gt;&lt;h2&gt; Qps %1&lt;/center&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qps.cpp" line="1912"/>
+        <location filename="../qps.cpp" line="1911"/>
         <source>&lt;h2&gt; Qps %1 - A Visual Process Manager &lt;/h2&gt; %2 using Qt library %3&lt;br&gt;&lt;br&gt;&lt;b&gt;Source: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps&quot;&gt;https://github.com/lxqt/qps/&lt;/a&gt;&lt;br&gt;&lt;b&gt;Bugtracker: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps/issues&quot;&gt;https://github.com/lxqt/qps/issues&lt;/a&gt;&lt;br&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qps.cpp" line="1932"/>
+        <location filename="../qps.cpp" line="1931"/>
         <source>&lt;b&gt;Original Qps by&lt;/b&gt;&lt;br&gt;Mattias Engdegård (f91-men@nada.kth.se)&lt;br&gt;&lt;br&gt;&lt;b&gt;Contributors&lt;/b&gt;&lt;br&gt;Olivier.Daudel@u-paris10.fr&lt;br&gt;jsanchez@todounix.homeip.net &lt;br&gt;daehyun.yang@gmail.com &lt;br&gt;Luís Pereira (luis.artur.pereira@gmail.com)&lt;br&gt;Alf Gaida (agaida@siduction.org)&lt;br&gt;Paulo Lieuthier (paulolieuthier@gmail.com)&lt;br&gt;Jerome Leclanche (jerome@leclan.ch)&lt;br&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qps.cpp" line="1970"/>
+        <location filename="../qps.cpp" line="1969"/>
         <source>&lt;H1&gt;QPS Help&lt;/H1&gt;Updated: May 24 2005&lt;BR&gt;&lt;A HREF=&quot;http://kldp.net/projects/qps&quot;&gt;http://kldp.net/projects/qps&lt;/A&gt;&lt;HR&gt;&lt;table style=&quot;text-align: center; width: 100%;&quot; border=&quot;1&quot; cellpadding=&quot;1&quot; cellspacing=&quot;0&quot;&gt;  &lt;tbody&gt;    &lt;tr&gt;      &lt;td style=&quot;vertical-align: top; background-color: rgb(204, 204, 204);&quot;&gt;Quit      &lt;/td&gt;      &lt;td &gt;&amp;nbsp; CTRL + q , CTRL + x      &lt;/td&gt;    &lt;/tr&gt;    &lt;tr&gt;      &lt;td style=&quot;vertical-align: top; background-color: rgb(204, 204, 204);&quot;&gt;Update      &lt;/td&gt;      &lt;td&gt;&amp;nbsp;Space , Enter       &lt;/td&gt;    &lt;/tr&gt;    &lt;tr&gt;&lt;td&gt; process Terminate &lt;/td&gt;  &lt;td&gt; ALT + T , DELETE &lt;/td&gt; &lt;/tr&gt;    &lt;tr&gt;&lt;td&gt; process Kill &lt;/td&gt;  &lt;td&gt; ALT + K  &lt;/td&gt; &lt;/tr&gt;  &lt;/tbody&gt;&lt;/table&gt;</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1622,12 +1627,12 @@ keluar dengan status </translation>
 <context>
     <name>SearchBox</name>
     <message>
-        <location filename="../misc.cpp" line="765"/>
+        <location filename="../misc.cpp" line="760"/>
         <source>PID, COMMAND, USER...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="766"/>
+        <location filename="../misc.cpp" line="761"/>
         <source>Filter</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1747,7 +1752,7 @@ keluar dengan status </translation>
 <context>
     <name>StatusBar</name>
     <message>
-        <location filename="../misc.cpp" line="807"/>
+        <location filename="../misc.cpp" line="796"/>
         <source>Process count: %1</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1772,7 +1777,7 @@ keluar dengan status </translation>
 <context>
     <name>UFrame</name>
     <message>
-        <location filename="../misc.cpp" line="615"/>
+        <location filename="../misc.cpp" line="610"/>
         <source>title</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1780,17 +1785,17 @@ keluar dengan status </translation>
 <context>
     <name>WatchdogDialog</name>
     <message>
-        <location filename="../watchdogdialog.cpp" line="193"/>
+        <location filename="../watchdogdialog.cpp" line="191"/>
         <source>if process start</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../watchdogdialog.cpp" line="194"/>
+        <location filename="../watchdogdialog.cpp" line="192"/>
         <source>if process finish</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../watchdogdialog.cpp" line="217"/>
+        <location filename="../watchdogdialog.cpp" line="215"/>
         <source>select condition</source>
         <translation type="unfinished"></translation>
     </message>
